[pLog-svn] r2547 - plog/branches/plog-1.0.2/class/dao

jondaley at devel.plogworld.net jondaley at devel.plogworld.net
Thu Nov 10 02:10:43 GMT 2005


Author: jondaley
Date: 2005-11-10 02:09:26 +0000 (Thu, 10 Nov 2005)
New Revision: 2547

Modified:
   plog/branches/plog-1.0.2/class/dao/articles.class.php
Log:
added code to get blog specific time offset when adding an article.  This seems strange that it wasn't already here - people use this, right?  removed unused textFilter object.

Modified: plog/branches/plog-1.0.2/class/dao/articles.class.php
===================================================================
--- plog/branches/plog-1.0.2/class/dao/articles.class.php	2005-11-09 15:33:44 UTC (rev 2546)
+++ plog/branches/plog-1.0.2/class/dao/articles.class.php	2005-11-10 02:09:26 UTC (rev 2547)
@@ -695,13 +695,18 @@
          */
         function addArticle( &$newArticle )
         {
-            // first, we build up the query
-            $filter = new Textfilter();
+                // all this just to get the blog offset.
+            $blogInfo = $this->blogs->getBlogInfo( $newArticle->getBlog() );
+            $blogSettings = $blogInfo->getSettings();
+            $timeDiff = $blogSettings->getValue( 'time_offset' );
+            $articleDate = Timestamp::getDateWithOffset( $newArticle->getDate(), -($timeDiff));
+
+                // first, we build up the query
             $query = "INSERT INTO ".$this->getPrefix()."articles( user_id,blog_id,status,date,properties, slug )
                       VALUES ( ".$newArticle->getUser().",".
                       $newArticle->getBlog().",'".
                       $newArticle->getStatus()."','".
-                      $newArticle->getDate()."','".
+                      $articleDate."','".
                       serialize($newArticle->getProperties())."','".
 					  $newArticle->getPostSlug()."');";
             // and then we send it to the db
@@ -822,7 +827,6 @@
         {
             // we have to build up the query, which will be pretty long...
             $articleDate = Timestamp::getDateWithOffset( $article->getDate(), -($article->getTimeOffset()));
-            $filter = new Textfilter();
 
             $query = "UPDATE ".$this->getPrefix()."articles SET id = ".$article->getId().
                      ", user_id = ".$article->getUser().




More information about the pLog-svn mailing list